// Beyond Institutional Design: Explaining the Performance of International Organizations
// Ranjit Lall
// Replication code for analyses based on multiple imputation

// cd

// Main analyses
use "data.imputed.dta"
summarize
mi import flong, m(imp) id(IO) imp(staff-perf_den)

foreach v of var uk_index aus_index net_index swe_index perf_den {
        su `v', meanonly
        gen new_`v' = (`v' - r(min))/(r(max) - r(min))
 }

egen avg_perf = rowmean(new_uk_index new_aus_index new_net_index new_swe_index new_perf_den)

// Table 2, Model 6

mi estimate: reg avg_perf dfpa staff field age, robust

// Table 3, Model 6

mi estimate: reg avg_perf djpa staff field age, robust

// Robustness checks

// Additional controls

clear
use "data.imputed.2.dta"
summarize
mi import flong, m(imp) id(IO) imp(staff-perf_den)

foreach v of var uk_index aus_index net_index swe_index perf_den {
        su `v', meanonly
        gen new_`v' = (`v' - r(min))/(r(max) - r(min))
 }

egen avg_perf = rowmean(new_uk_index new_aus_index new_net_index new_swe_index new_perf_den)

// Table A11, Model 6

mi estimate: reg avg_perf dfpa staff field age development education environment humanitarian health asymmetry voting geographical, robust

// Table A12, Model 6

mi estimate: reg avg_perf djpa staff field age development education environment humanitarian health asymmetry voting geographical, robust

// Excluding INGOs and PPPs

clear
use "data.imputed.dta"
summarize

mi import flong, m(imp) id(IO) imp(staff-perf_den)

foreach v of var uk_index aus_index net_index swe_index perf_den {
        su `v', meanonly
        gen new_`v' = (`v' - r(min))/(r(max) - r(min))
 }

egen avg_perf = rowmean(new_uk_index new_aus_index new_net_index new_swe_index new_perf_den)

drop if IO == 6| IO == 14| IO == 15| IO == 17| IO == 13| IO == 20| IO == 23

// Table A14, Model 6

mi estimate: reg avg_perf dfpa staff field age, robust

// Table A15, Model 6

mi estimate: reg avg_perf djpa staff field age, robust

// Instrumental variables analysis

clear
use "data.imputed.dta"
summarize

mi import flong, m(imp) id(IO) imp(staff-perf_den)

foreach v of var uk_index aus_index net_index swe_index perf_den {
        su `v', meanonly
        gen new_`v' = (`v' - r(min))/(r(max) - r(min))
 }

egen avg_perf = rowmean(new_uk_index new_aus_index new_net_index new_swe_index new_perf_den)

// Table A20, Model 6

xi: mi estimate, cmdok post: ivreg2 avg_perf staff field age (dfpa = tcs), first endog(dfpa) small rf savefirst savefprefix(first)
mi estimate: reg dfpa staff field age tcs

// Table A21, Model 6

xi: mi estimate, cmdok post: ivreg2 avg_perf staff field age (dfpa = tcq), first endog(dfpa) small rf savefirst savefprefix(first)
mi estimate: reg dfpa staff field age tcq






